"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TringImage = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeFastImage = _interopRequireDefault(require("react-native-fast-image"));
var _utils = require("../../shared/utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const DEFAULT_IMAGE_SIZE = 24;
const DEFAULT_RADIUS_DIVIDER = 2;
const TringImage = _ref => {
  let {
    name,
    size = DEFAULT_IMAGE_SIZE,
    style,
    backgroundColor = 'transparent',
    type = 'standard',
    resizeMode = 'contain',
    url,
    fallback = false,
    fallbackSource,
    defaultImageStyle,
    ...props
  } = _ref;
  const [showPlaceholder, setShowPlaceholder] = (0, _react.useState)(false);
  const [isLoadEnd, setIsLoadEnd] = (0, _react.useState)(false);
  const isRounded = type === 'round';
  const imageStyle = {
    height: size,
    width: size
  };
  const borderStyle = {
    borderRadius: isRounded ? size / DEFAULT_RADIUS_DIVIDER : 0,
    backgroundColor
  };
  let isValidImageUrl = true;
  const imageUrlPathArray = (0, _utils.isNotEmpty)(url) && (url === null || url === void 0 ? void 0 : url.split('/'));
  if (!imageUrlPathArray || !(0, _utils.isNonEmptyArray)(imageUrlPathArray) || imageUrlPathArray.length < 3 || !(0, _utils.isNotEmpty)(imageUrlPathArray[3])) {
    isValidImageUrl = false;
  }
  if (!(0, _utils.isNotEmpty)(name) && !isValidImageUrl) {
    name = fallback && fallbackSource ? fallbackSource : null;
  }
  const onLoadEnd = () => setIsLoadEnd(true);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, !isLoadEnd && fallback && fallbackSource && /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: fallbackSource,
    style: [imageStyle, borderStyle, styles.defaultImage, defaultImageStyle]
  }), /*#__PURE__*/_react.default.createElement(_reactNativeFastImage.default, _extends({
    style: _reactNative.StyleSheet.flatten([imageStyle, borderStyle, style]),
    source: name ? name : showPlaceholder ? fallbackSource : {
      uri: url
    },
    onError: () => !name && setShowPlaceholder(true),
    resizeMode: resizeMode,
    onLoadEnd: onLoadEnd
  }, props)));
};
exports.TringImage = TringImage;
const styles = _reactNative.StyleSheet.create({
  defaultImage: {
    position: 'absolute',
    top: 0,
    bottom: 0,
    left: 0,
    right: 0,
    overflow: 'hidden',
    width: '100%',
    height: '100%'
  }
});
//# sourceMappingURL=TringImage.js.map