"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.InputField = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _utilities = require("../utilities");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const renderText = (content, defaultProps, style) => (0, _utilities.renderNode)(_reactNative.Text, content, {
  ...defaultProps,
  style: _reactNative.StyleSheet.flatten([style, defaultProps && defaultProps.style])
});
const Input = (_ref, ref) => {
  let {
    containerStyle,
    disabled,
    disabledInputStyle,
    inputContainerStyle,
    leftIcon,
    leftIconContainerStyle,
    rightIcon,
    rightIconContainerStyle,
    labelContainerStyle,
    errorContainerStyle,
    inputStyle,
    errorProps,
    errorStyle,
    errorMessage,
    label,
    labelStyle,
    labelProps,
    renderErrorMessage,
    inputProps,
    onChangeText,
    onSubmitEditing
  } = _ref;
  const inputRef = _react.default.useRef();
  (0, _react.useEffect)(() => {
    _reactNative.I18nManager.isRTL && _reactNative.I18nManager.forceRTL(true);
  }, []);
  (0, _react.useImperativeHandle)(ref, () => ({
    focus: () => {
      inputRef.current.focus();
    },
    blur: () => {
      inputRef.current.blur();
    },
    clear: () => {
      inputRef.current.clear();
    },
    isFocused: () => {
      inputRef.current.isFocused();
    },
    setNativeProps: nativeProps => {
      inputRef.current.setNativeProps(nativeProps);
    }
  }));
  const hideErrorMessage = !renderErrorMessage && !errorMessage;
  const renderLeftIcon = () => {
    if (!leftIcon) return null;
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: _reactNative.StyleSheet.flatten([styles.iconContainer, leftIconContainerStyle])
    }, (0, _utilities.renderNode)(null, leftIcon));
  };
  const renderRightIcon = () => {
    if (!rightIcon) return null;
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: _reactNative.StyleSheet.flatten([styles.iconContainer, rightIconContainerStyle])
    }, (0, _utilities.renderNode)(null, rightIcon));
  };
  const renderErrorText = () => /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _reactNative.StyleSheet.flatten([styles.defaultLabelContainer, errorContainerStyle])
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, _extends({}, errorProps, {
    style: _reactNative.StyleSheet.flatten([styles.defaultErrorStyle, errorStyle && errorStyle, hideErrorMessage && styles.hideErrorStyle])
  }), errorMessage));
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _reactNative.StyleSheet.flatten([styles.container, containerStyle])
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _reactNative.StyleSheet.flatten([styles.defaultLabelContainer, labelContainerStyle])
  }, renderText(label, {
    style: labelStyle,
    ...labelProps
  }, styles.defaultLabelStyle)), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _reactNative.StyleSheet.flatten([styles.defaultInputContainerStyle, inputContainerStyle])
  }, renderLeftIcon(), /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, _extends({
    ref: inputRef,
    underlineColorAndroid: "transparent",
    editable: !disabled,
    style: _reactNative.StyleSheet.flatten([styles.defaultInputStyle, inputStyle, disabled && styles.disabledInput, disabled && disabledInputStyle, _reactNative.I18nManager.isRTL && styles.rtlInputStyle]),
    onChangeText: onChangeText && onChangeText,
    onSubmitEditing: onSubmitEditing && onSubmitEditing
  }, inputProps)), renderRightIcon()), renderErrorText());
};
const InputField = /*#__PURE__*/_react.default.forwardRef(Input);
exports.InputField = InputField;
const styles = _reactNative.StyleSheet.create({
  container: {
    width: '100%',
    paddingHorizontal: 10
  },
  disabledInput: {
    opacity: 0.5
  },
  iconContainer: {
    height: 40,
    justifyContent: 'center',
    alignItems: 'center',
    paddingRight: 4,
    marginVertical: 4
  },
  defaultLabelStyle: {
    fontSize: 16,
    color: 'grey',
    fontWeight: 'bold'
  },
  defaultInputContainerStyle: {
    flexDirection: 'row',
    borderBottomWidth: 1,
    alignItems: 'center',
    borderColor: 'grey'
  },
  defaultInputStyle: {
    color: 'black',
    fontSize: 18,
    flex: 1,
    minHeight: 40,
    textAlign: 'left'
  },
  defaultErrorStyle: {
    marginVertical: 5,
    fontSize: 12,
    color: 'red'
  },
  hideErrorStyle: {
    height: 0,
    margin: 0,
    padding: 0
  },
  rtlInputStyle: {
    textAlign: 'right'
  },
  defaultLabelContainer: {
    flex: 1,
    alignItems: 'flex-start'
  }
});
//# sourceMappingURL=inputField.js.map