import React, { useMemo, useState } from 'react';
import { View, StyleSheet } from 'react-native';
export let DashedLineAxisType;
(function (DashedLineAxisType) {
  DashedLineAxisType[DashedLineAxisType["HORIZONTAL"] = 0] = "HORIZONTAL";
  DashedLineAxisType[DashedLineAxisType["VERTICAL"] = 1] = "VERTICAL";
})(DashedLineAxisType || (DashedLineAxisType = {}));
export const DashedLine = _ref => {
  let {
    axis = DashedLineAxisType.HORIZONTAL,
    dashGap = 2,
    dashLength = 4,
    dashThickness = 2,
    dashColor = '#000',
    dashStyle,
    containerStyle
  } = _ref;
  const [lineLength, setLineLength] = useState(0);
  const isRow = axis === DashedLineAxisType.HORIZONTAL;
  const numOfDashes = Math.ceil(lineLength / (dashGap + dashLength));
  const dashStyles = useMemo(() => ({
    width: isRow ? dashLength : dashThickness,
    height: isRow ? dashThickness : dashLength,
    marginRight: isRow ? dashGap : 0,
    marginBottom: isRow ? 0 : dashGap,
    backgroundColor: dashColor
  }), [dashColor, dashGap, dashLength, dashThickness, isRow]);
  const onLayout = event => {
    const {
      width,
      height
    } = event.nativeEvent.layout;
    setLineLength(isRow ? width : height);
  };
  return /*#__PURE__*/React.createElement(View, {
    testID: "dashedLineMainView",
    onLayout: onLayout,
    style: [containerStyle, isRow ? styles.row : styles.column]
  }, [...Array(numOfDashes)].map((_, i) => {
    return /*#__PURE__*/React.createElement(View, {
      key: i,
      style: [dashStyles, dashStyle]
    });
  }));
};
const styles = StyleSheet.create({
  row: {
    flexDirection: 'row'
  },
  column: {
    flexDirection: 'column'
  }
});
//# sourceMappingURL=DashedLine.js.map