import React, { useRef, useState } from 'react';
import { FlatList, StyleSheet, Text, TouchableOpacity, Modal, View } from 'react-native';
export const Dropdown = _ref => {
  let {
    label,
    data,
    onSelect,
    mainContainerStyle,
    listContainerStyle,
    itemStyle
  } = _ref;
  const DropdownButton = useRef();
  const [visible, setVisible] = useState(false);
  const [selected, setSelected] = useState(undefined);
  const [dropdownTop, setDropdownTop] = useState(0);
  const toggleDropdown = () => {
    visible ? setVisible(false) : openDropdown();
  };
  const openDropdown = () => {
    DropdownButton.current.measure((_fx, _fy, _w, h, _px, py) => {
      setDropdownTop(py + h);
    });
    setVisible(true);
  };
  const onItemPress = item => {
    setSelected(item);
    if (onSelect) {
      onSelect(item);
    }
    setVisible(false);
  };
  const renderItem = _ref2 => {
    let {
      item
    } = _ref2;
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      testID: "renderItemTouchableOpacity1",
      style: StyleSheet.flatten([styles.item, itemStyle]),
      onPress: () => onItemPress(item)
    }, /*#__PURE__*/React.createElement(Text, null, item.label));
  };
  const renderDropdown = () => {
    return /*#__PURE__*/React.createElement(Modal, {
      visible: visible,
      transparent: true,
      animationType: "none"
    }, /*#__PURE__*/React.createElement(TouchableOpacity, {
      testID: "renderDropdownTouchableOpacity",
      style: StyleSheet.flatten([styles.overlay, mainContainerStyle]),
      onPress: () => setVisible(false)
    }, /*#__PURE__*/React.createElement(View, {
      style: StyleSheet.flatten([styles.dropdown, listContainerStyle, {
        top: dropdownTop
      }])
    }, /*#__PURE__*/React.createElement(FlatList, {
      data: data,
      renderItem: renderItem,
      keyExtractor: (_, index) => index.toString()
    }))));
  };
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    testID: "mainTouchableOpacity",
    ref: DropdownButton,
    style: styles.button,
    onPress: toggleDropdown
  }, renderDropdown(), /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, selected && selected.label || label));
};
const styles = StyleSheet.create({
  button: {
    flexDirection: 'row',
    alignItems: 'center',
    backgroundColor: '#efefef',
    height: 50,
    zIndex: 1
  },
  buttonText: {
    flex: 1,
    textAlign: 'center'
  },
  icon: {
    marginRight: 10
  },
  dropdown: {
    position: 'absolute',
    backgroundColor: '#fff',
    width: '100%',
    shadowColor: '#000000',
    shadowRadius: 4,
    shadowOffset: {
      height: 4,
      width: 0
    },
    shadowOpacity: 0.5
  },
  overlay: {
    width: '100%',
    height: '100%'
  },
  item: {
    paddingHorizontal: 10,
    paddingVertical: 10,
    borderBottomWidth: 1
  }
});
//# sourceMappingURL=dropDown.js.map