import React, { useState, useEffect } from 'react';
import { Animated, Easing, StyleSheet } from 'react-native';
import { colors } from '../../shared/colors';
export const HorizontalProgress = _ref => {
  let {
    color = 'blue',
    initialProgress = 0,
    progress = 0,
    duration = 2000
  } = _ref;
  const [progressState, setProgressState] = useState(0);
  useEffect(() => {
    setTimeout(() => {
      animateProgress();
    }, 300);
  }, [initialProgress]);
  const progAnimation = new Animated.Value(initialProgress);
  const animateProgress = () => {
    progAnimation.addListener(_ref2 => {
      let {
        value
      } = _ref2;
      setProgressState(value);
    });
    Animated.timing(progAnimation, {
      toValue: progress,
      duration,
      easing: Easing.quad,
      useNativeDriver: true
    }).start();
  };
  return /*#__PURE__*/React.createElement(Animated.View, {
    testID: 'progress',
    style: styles.container
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.progressBarStyle, {
      backgroundColor: color,
      width: `${progressState}%`
    }]
  }));
};
export const styles = StyleSheet.create({
  container: {
    width: '100%',
    height: 8,
    borderRadius: 4,
    backgroundColor: colors.greyLight
  },
  progressBarStyle: {
    ...StyleSheet.absoluteFillObject,
    backgroundColor: colors.blue,
    borderRadius: 6
  }
});
//# sourceMappingURL=HorizontalProgress.js.map